import { __decorate, __awaiter, __generator, __extends } from 'tslib';
import { ɵɵdefineInjectable, Injectable, ɵɵinject, Injector, Component, NgModule } from '@angular/core';
import { KeycloakService } from 'keycloak-angular';
import { HttpClient } from '@angular/common/http';
import { CommonModule } from '@angular/common';
import { MatIconModule } from '@angular/material/icon';
import { MatMenuModule } from '@angular/material/menu';

var EkinasHeaderService = /** @class */ (function () {
    function EkinasHeaderService() {
    }
    EkinasHeaderService.ɵprov = ɵɵdefineInjectable({ factory: function EkinasHeaderService_Factory() { return new EkinasHeaderService(); }, token: EkinasHeaderService, providedIn: "root" });
    EkinasHeaderService = __decorate([
        Injectable({
            providedIn: 'root'
        })
    ], EkinasHeaderService);
    return EkinasHeaderService;
}());

var backendUrl = 'http://localhost:8080/movies-meta-api';
var bavicUrl = 'http://localhost:8081/ekinas-bavic-api';
var keycloakConfig = {
    url: 'http://ekinas:8080/auth/',
    realm: 'ekinas-int',
    clientId: 'ekinas-client',
};
var environment = {
    keycloakConfig: keycloakConfig,
    production: false,
    backendUrl: backendUrl,
    bavicUrl: bavicUrl,
    ENV_NAME: 'Development',
    VERSION_URL: backendUrl + ':4200/assets/version.json',
    MOVIES_URL: backendUrl + '/information-objects',
    MICROSERVICES_URL: backendUrl + '/microservices-urls',
    OSDS_URL: backendUrl + '/original-storages-data',
    COPYRIGHTS_URL: backendUrl + '/copyrights',
    DIGITAL_COPIES_URL: backendUrl + '/digital-copies',
    TAPES_DIGITALIZATIONS_URL: backendUrl + '/tapes-digitalizations',
    TAPES_INSPECTIONS_URL: backendUrl + '/tapes-inspections',
};
/*
 * For easier debugging in development mode, you can import the following file
 * to ignore zone related error stack frames such as `zone.run`, `zoneDelegate.invokeTask`.
 *
 * This import should be commented out in production mode because it will have a negative impact
 * on performance if an error is thrown.
 */
// import 'zone.js/dist/zone-error';  // Included with Angular CLI.

var AuthenticatingController = /** @class */ (function () {
    function AuthenticatingController(injector) {
        this.injector = injector;
        this.authData = this.injector.get(KeycloakService);
    }
    AuthenticatingController.prototype.hasRole = function (role) {
        return this.authData.isUserInRole(role);
    };
    AuthenticatingController.prototype.hasAnyRole = function (roles) {
        var _this = this;
        return roles.filter(function (r) { return _this.authData.isUserInRole(r); }).length > 0;
    };
    AuthenticatingController.prototype.getGrantedRoles = function () {
        return this.authData.getUserRoles();
    };
    AuthenticatingController.prototype.hasRoleInClient = function (clientId) {
        var kra = this.authData.getKeycloakInstance().resourceAccess;
        return kra && kra[clientId] && kra[clientId].roles.length > 0;
    };
    AuthenticatingController.prototype.getUserInfo = function () {
        return this.authData.loadUserProfile();
    };
    AuthenticatingController.prototype.isLoggedIn = function () {
        return this.authData.isLoggedIn();
    };
    AuthenticatingController.prototype.redirectToAccountEditUrl = function (returnUrl) {
        if (!returnUrl) {
            returnUrl = window.location.href;
        }
        window.open(environment.keycloakConfig.url
            + 'realms/' + environment.keycloakConfig.realm
            + '/account/?referrer_uri='
            + returnUrl, '_account');
    };
    return AuthenticatingController;
}());

var MicroservicesUrls = /** @class */ (function () {
    function MicroservicesUrls(metadataUrl, administrationUrl, eservicesUrl, classifierUrl) {
        if (metadataUrl === void 0) { metadataUrl = ''; }
        if (administrationUrl === void 0) { administrationUrl = ''; }
        if (eservicesUrl === void 0) { eservicesUrl = ''; }
        if (classifierUrl === void 0) { classifierUrl = ''; }
        this.metadataUrl = metadataUrl;
        this.administrationUrl = administrationUrl;
        this.eservicesUrl = eservicesUrl;
        this.classifierUrl = classifierUrl;
    }
    return MicroservicesUrls;
}());

var MicroservicesUrlsService = /** @class */ (function () {
    function MicroservicesUrlsService(http) {
        this.http = http;
        this.microservicesUrlsBackendUrl = environment.MICROSERVICES_URL;
    }
    MicroservicesUrlsService.prototype.load = function () {
        return __awaiter(this, void 0, void 0, function () {
            var _this = this;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.http.get(this.microservicesUrlsBackendUrl + '/all', {}).toPromise().then(function (c) {
                            _this.microservicesUrls = c;
                        })];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    MicroservicesUrlsService.prototype.getUrl = function () {
        return this.microservicesUrls;
    };
    MicroservicesUrlsService.ctorParameters = function () { return [
        { type: HttpClient }
    ]; };
    MicroservicesUrlsService.ɵprov = ɵɵdefineInjectable({ factory: function MicroservicesUrlsService_Factory() { return new MicroservicesUrlsService(ɵɵinject(HttpClient)); }, token: MicroservicesUrlsService, providedIn: "root" });
    MicroservicesUrlsService = __decorate([
        Injectable({
            providedIn: 'root'
        })
    ], MicroservicesUrlsService);
    return MicroservicesUrlsService;
}());

var EkinasHeaderComponent = /** @class */ (function (_super) {
    __extends(EkinasHeaderComponent, _super);
    function EkinasHeaderComponent(microservicesUrlsService, injector) {
        var _this = _super.call(this, injector) || this;
        _this.microservicesUrlsService = microservicesUrlsService;
        _this.microservicesUrls = new MicroservicesUrls();
        _this.firstname = '';
        _this.lastname = '';
        _this.microservicesUrls = microservicesUrlsService.getUrl();
        _this.getUserInfo().then(function (keycloakProfile) {
            _this.firstname = keycloakProfile.firstName;
            _this.lastname = keycloakProfile.lastName;
        });
        return _this;
    }
    EkinasHeaderComponent.prototype.logout = function () {
        this.authData.logout().then(function () {
        });
    };
    EkinasHeaderComponent.ctorParameters = function () { return [
        { type: MicroservicesUrlsService },
        { type: Injector }
    ]; };
    EkinasHeaderComponent = __decorate([
        Component({
            selector: 'lib-ekinas-header',
            template: "<div [ngClass]=\"'main-menu-div'\">\r\n  <div [ngClass]=\"'red-circle'\"></div>\r\n  <div [ngClass]=\"'header-main-title'\">E-KINAS</div>\r\n  <div [ngClass]=\"'header-sub-title'\">Vidin\u0117 sistema</div>\r\n  <div [ngClass]=\"'header-links-div'\">\r\n    <a href=\"{{microservicesUrls.metadataUrl + '/main/movies'}} \">Film\u0173 s\u0105ra\u0161as</a>\r\n    <a href=\"{{microservicesUrls.administrationUrl + '/upload'}} \">Duomen\u0173 \u012Fvedimas</a>\r\n    <a href=\"{{microservicesUrls.administrationUrl + '/tasks'}} \">U\u017Eduotys</a>\r\n    <a href=\"{{microservicesUrls.eservicesUrl + '/list'}} \">El. paslaug\u0173 s\u0105ra\u0161as</a>\r\n    <div>\r\n      <div [ngClass]=\"['user-name', 'user-name-upper']\">{{firstname}}</div>\r\n      <div [ngClass]=\"['user-name', 'user-name-lower']\">{{lastname}}</div>\r\n    </div>\r\n    <div [ngClass]=\"'white-circle-user'\" [matMenuTriggerFor]=\"menu\">\r\n      <mat-icon class=\"material-icons-outlined\">person</mat-icon>\r\n      <mat-menu #menu=\"matMenu\" xPosition=\"before\">\r\n        <button mat-menu-item disabled>\r\n          <span [ngClass]=\"'user-menu-span-name'\">{{firstname}} {{lastname}}</span>\r\n        </button>\r\n        <button mat-menu-item [ngClass]=\"'user-menu'\" (click)=\"logout()\">\r\n          <mat-icon [ngClass]=\"'user-menu-icon'\">logout</mat-icon>\r\n          <span [ngClass]=\"'user-menu-span'\">ATSIJUNGTI</span>\r\n        </button>\r\n      </mat-menu>\r\n    </div>\r\n    <div [ngClass]=\"'white-circle-messages'\">\r\n      <mat-icon class=\"material-icons-outlined\" matBadgeSize=\"small\" matBadgePosition=\"above after\" matBadge=\"15\" matBadgeColor=\"warn\">email</mat-icon>\r\n    </div>\r\n  </div>\r\n</div>\r\n",
            styles: ["@import url(https://fonts.googleapis.com/css?family=Montserrat&display=swap);@import url(https://fonts.googleapis.com/css2?family=Krona+One&display=swap);.main-menu-div{position:absolute;top:0;left:0;width:100%;height:97px;background:no-repeat padding-box #000;opacity:1}.red-circle{position:sticky;top:32px;left:138px;width:36px;height:36px;border-radius:50%;background:no-repeat padding-box #e21c3e;opacity:1;margin:32px auto 29px 138px}.header-main-title{position:absolute;top:37px;bottom:35px;left:193px;width:110px;height:25px;text-align:left;font:20px/25px Krona One;letter-spacing:0;color:#fff;opacity:1}.header-sub-title{position:absolute;top:59px;left:193px;width:121px;height:19px;text-align:left;font:600 16px/19px Montserrat;letter-spacing:0;color:#fff;opacity:1}.header-links-div{position:absolute;top:40px;left:350px;color:#fff;text-align:left;font:600 16px/19px Montserrat;letter-spacing:0;opacity:1}a{color:#fff;margin-left:60px}.white-circle-search{position:absolute;top:-10px;left:1020px;width:48px;height:48px;border-radius:50%;background:no-repeat padding-box #fff;opacity:1}.white-circle-user{position:absolute;top:-10px;left:1240px;width:48px;height:48px;border-radius:50%;background:no-repeat padding-box #fff;opacity:1;cursor:pointer}.white-circle-messages{position:absolute;top:-10px;left:1300px;width:48px;height:48px;border-radius:50%;background:no-repeat padding-box #fff;opacity:1}mat-icon{position:absolute;margin:13px auto auto 13px;display:block}.user-name{min-width:125px;position:absolute;left:1100px;font-size:14px;font-family:Montserrat,serif;font-weight:400;text-transform:uppercase;text-align:right}.user-name-upper{top:-3px}.user-name-lower{top:12px}.user-menu-icon{margin-left:5px;color:#000}.user-menu-span{margin-left:35px;font-family:Montserrat,serif;font-size:12px}.user-menu-span-name{margin-left:35px;font-family:Montserrat,serif;font-size:12px;text-transform:uppercase;font-weight:800}.user-menu{width:200px;font-weight:900;color:#2d2d2d}"]
        })
    ], EkinasHeaderComponent);
    return EkinasHeaderComponent;
}(AuthenticatingController));

var EkinasHeaderModule = /** @class */ (function () {
    function EkinasHeaderModule() {
    }
    EkinasHeaderModule = __decorate([
        NgModule({
            declarations: [EkinasHeaderComponent],
            imports: [CommonModule, MatIconModule, MatMenuModule],
            exports: [EkinasHeaderComponent],
            providers: [HttpClient, MicroservicesUrlsService]
        })
    ], EkinasHeaderModule);
    return EkinasHeaderModule;
}());

/*
 * Public API Surface of ekinas-header
 */

/**
 * Generated bundle index. Do not edit.
 */

export { EkinasHeaderComponent, EkinasHeaderModule, EkinasHeaderService, AuthenticatingController as ɵa, MicroservicesUrlsService as ɵb };
//# sourceMappingURL=ekinas-header.js.map
